@@ -77,7 +77,7 @@ class Client:
         """Build HTTP params."""
         params = {}
         if views:
-            params["view_name"] = views
+            params["views"] = views
 
         if occurrences:
             params["occurrences"] = occurrences
@@ -358,7 +358,6 @@ class Client:
                 data = json.dumps(translate)
                 self.pipeline.set(_id, data)
 
-                # NOTE: Build indexes for search/data access.
                 if _snake:
                     self.pipeline.hset(_SNAKE_NAME_MAP, _snake, _id)
 
@@ -368,12 +367,10 @@ class Client:
                 for view in _views:
                     views[view].append(_id)
                     self.pipeline.hset(_VIEWS_ID_MAP, _id, view)
-                    self.__expire(_VIEWS_ID_MAP)
 
                 for occurrence in _occurrences:
                     occurrences[occurrence].append(_id)
                     self.pipeline.hset(_OCCURRENCES_ID_MAP, _id, occurrence)
-                    self.__expire(_OCCURRENCES_ID_MAP)
 
             # NOTE: Cache freshly retrieved items.
             for view, keys in views.items():
@@ -383,6 +380,9 @@ class Client:
                 self.__set_occurrence(language, occurrence, ids=keys)
 
             self.pipeline.execute()
+            self.__expire(_VIEWS_ID_MAP)
+            self.__expire(_OCCURRENCES_ID_MAP)
+
             return _cache
 
         result = _cache_warmup()
