@@ -215,17 +215,31 @@ class TestTranslateClientModel(LiveServerTestCase):
         client = Client(config("TRANSLATE_ADDRESS", default="http://localhost"), port)
 
         language = "de"
-        _ = client.filter(
+        view_keys = client.filter(
             language,
             views=["translation_center"],
         )
-        _ = client.filter(
+        occur_keys = client.filter(
             language,
             occurrences=[
                 "new_mdt/apps/mdt_apartments/api/docs.py",
             ],
         )
 
+        for item in view_keys.values():
+            views = item.get("key").get("views")
+            assert views, "Ensure that method don't return keys with value None"
+            assert (
+                "translation_center" in views
+            ), "Ensure that key with requested view is returned"
+
+        for item in occur_keys.values():
+            occurrences = item.get("key").get("occurrences")
+            assert occurrences, "Ensure that method don't return keys with value None"
+            assert (
+                "new_mdt/apps/mdt_apartments/api/docs.py" in occurrences
+            ), "Ensure that key with requested occurrence is returned"
+
         maps_no_expire = [
             f"{language}_id_name",
             f"{language}_snake_name",
@@ -245,7 +259,7 @@ class TestTranslateClientModel(LiveServerTestCase):
             assert cache.hgetall(key), "Should have returned some values."
             assert (
                 cache.ttl(key) == 2700
-            ), "TTL for views and occurrences should be 45 minutes or 2700 seconds"
+            ), "TTL for views and occurrences should be 45 minutes or 2700 seconds."
 
         assert client.snake_key(language, "admin_dossier_downloading")
 
